@@ -19,7 +19,7 @@ ggtheme <- function(panelback = "white") {
     panel.background = element_rect(fill = panelback),
     panel.grid = element_blank(),
     axis.ticks =  element_line(colour = "black"),
-    panel.margin =unit(0.25, "lines"),  # requires package grid
+    panel.spacing =unit(0.25, "lines"),  # requires package grid
     panel.border = element_rect(fill = NA, colour="gray90"), 
     plot.title = element_text(size = 8,vjust=.5,hjust=0),
     axis.text = element_text(size=8),
